pub struct Scenario<'a> { /* private fields */ }Expand description
The representation of a scenario. A moment consisting of various events, the present actors and any predicates that apply to either.
Implementations
Sourceimpl<'a> Scenario<'a>
impl<'a> Scenario<'a>
Sourcepub fn parse(s: &'a str) -> Result<Self, ScenarioParsingError>
pub fn parse(s: &'a str) -> Result<Self, ScenarioParsingError>
Parses a scenario from a string.
let s = "<a (Red), b, c (Blue, Red); {(Green)}, {A: a}, {P: c (Blue)}> lambda a x pa_Blue(x); lambda a x pa_Red(x)";
let scenario = Scenario::parse(s).unwrap();
assert_eq!(scenario.to_string(), s);Errors
Will return an error if the Scenario is incorrectly formatted.
Sourceimpl<'a> Scenario<'a>
impl<'a> Scenario<'a>
Sourcepub fn all_scenarios(
actors: &[Actor<'a>],
event_kinds: &[PossibleEvent<'a>],
actor_properties: &[&'a str],
max_number_of_events: Option<usize>,
max_number_of_actors: Option<usize>,
max_number_of_properties: Option<usize>,
) -> ScenarioIterator<'a> ⓘ
pub fn all_scenarios( actors: &[Actor<'a>], event_kinds: &[PossibleEvent<'a>], actor_properties: &[&'a str], max_number_of_events: Option<usize>, max_number_of_actors: Option<usize>, max_number_of_properties: Option<usize>, ) -> ScenarioIterator<'a> ⓘ
Returns a ScenarioIterator which goes over all possible scenarios with the provided
actors and event descriptions
Sourceimpl<'a> Scenario<'a>
impl<'a> Scenario<'a>
Sourcepub fn new(
actors: Vec<Actor<'a>>,
thematic_relations: Vec<ThetaRoles<'a>>,
properties: BTreeMap<&'a str, Vec<Entity<'a>>>,
) -> Scenario<'a>
pub fn new( actors: Vec<Actor<'a>>, thematic_relations: Vec<ThetaRoles<'a>>, properties: BTreeMap<&'a str, Vec<Entity<'a>>>, ) -> Scenario<'a>
Create a new scenario.
Sourcepub fn thematic_relations(&self) -> &[ThetaRoles<'a>]
pub fn thematic_relations(&self) -> &[ThetaRoles<'a>]
Get the representation of all events as a slice of ThetaRoles.
Sourcepub fn properties(&self) -> &BTreeMap<&'a str, Vec<Entity<'a>>>
pub fn properties(&self) -> &BTreeMap<&'a str, Vec<Entity<'a>>>
Get the properties (e.g. what predicates apply) of the entities in a scenario.
Sourcepub fn questions(&self) -> &[RootedLambdaPool<'a, Expr<'a>>]
pub fn questions(&self) -> &[RootedLambdaPool<'a, Expr<'a>>]
Get the questions associated with a scenario (which may be empty if there are no questions).
Questions are representated as RootedLambdaPool which return a truth value.
Sourcepub fn question_mut(&mut self) -> &mut Vec<RootedLambdaPool<'a, Expr<'a>>>
pub fn question_mut(&mut self) -> &mut Vec<RootedLambdaPool<'a, Expr<'a>>>
Get a mutable reference to the questions of a scenario.
See Scenario::questions